@@ -1,3 +1,4 @@
+;;; -*- lexical-binding: t; -*-
 ;;; eide-project.el --- Emacs-IDE: Project management
 
 ;; Copyright © 2008-2025 Cédric Marie
@@ -168,116 +169,116 @@
   "Default C style."
   :tag "Default C style"
   :type 'string
-  :set '(lambda (param value) (set-default param value))
+  :set (lambda (param value) (set-default param value))
   :group 'eide-project)
 (defcustom eide-custom-project-default-init-command ""
   "This command is called before all \\='compile\\=' and \\='run\\=' commands."
   :tag "Default init command"
   :type 'string
-  :set '(lambda (param value) (set-default param value))
+  :set (lambda (param value) (set-default param value))
   :group 'eide-project)
 (defcustom eide-custom-project-default-compile-command-1 ""
   "Default compile command (1)."
   :tag "Default compile command (1)"
   :type 'string
-  :set '(lambda (param value) (set-default param value))
+  :set (lambda (param value) (set-default param value))
   :group 'eide-project)
 (defcustom eide-custom-project-default-compile-command-2 ""
   "Default compile command (2)."
   :tag "Default compile command (2)"
   :type 'string
-  :set '(lambda (param value) (set-default param value))
+  :set (lambda (param value) (set-default param value))
   :group 'eide-project)
 (defcustom eide-custom-project-default-compile-command-3 ""
   "Default compile command (3)."
   :tag "Default compile command (3)"
   :type 'string
-  :set '(lambda (param value) (set-default param value))
+  :set (lambda (param value) (set-default param value))
   :group 'eide-project)
 (defcustom eide-custom-project-default-compile-command-4 ""
   "Default compile command (4)."
   :tag "Default compile command (4)"
   :type 'string
-  :set '(lambda (param value) (set-default param value))
+  :set (lambda (param value) (set-default param value))
   :group 'eide-project)
 (defcustom eide-custom-project-default-run-command-1 ""
   "Default run command (1)."
   :tag "Default run command (1)"
   :type 'string
-  :set '(lambda (param value) (set-default param value))
+  :set (lambda (param value) (set-default param value))
   :group 'eide-project)
 (defcustom eide-custom-project-default-run-command-2 ""
   "Default run command (2)."
   :tag "Default run command (2)"
   :type 'string
-  :set '(lambda (param value) (set-default param value))
+  :set (lambda (param value) (set-default param value))
   :group 'eide-project)
 (defcustom eide-custom-project-default-debug-command ""
   "Default debug command."
   :tag "Default debug command"
   :type 'string
-  :set '(lambda (param value) (set-default param value))
+  :set (lambda (param value) (set-default param value))
   :group 'eide-project)
 (defcustom eide-custom-project-default-debug-program-1 ""
   "Default debug program (1)."
   :tag "Default debug program (1)"
   :type 'string
-  :set '(lambda (param value) (set-default param value))
+  :set (lambda (param value) (set-default param value))
   :group 'eide-project)
 (defcustom eide-custom-project-default-debug-program-2 ""
   "Default debug program (2)."
   :tag "Default debug program (2)"
   :type 'string
-  :set '(lambda (param value) (set-default param value))
+  :set (lambda (param value) (set-default param value))
   :group 'eide-project)
 (defcustom eide-custom-project-default-compile-error-old-path-regexp ""
   "Default compile error old path regexp (used to modify the path of filenames in
 the compilation buffer)."
   :tag "Default compile error old path regexp"
   :type 'string
-  :set '(lambda (param value) (set-default param value))
+  :set (lambda (param value) (set-default param value))
   :group 'eide-project)
 (defcustom eide-custom-project-default-compile-error-new-path-string ""
   "Default compile error new path string (used to modify the path of filenames in
 the compilation buffer)."
   :tag "Default compile error new path string"
   :type 'string
-  :set '(lambda (param value) (set-default param value))
+  :set (lambda (param value) (set-default param value))
   :group 'eide-project)
 (defcustom eide-custom-project-default-tags-exclude ""
   "Default space separated list of patterns (files or directories) to exclude when
 creating tags."
   :tag "Default tags exclude patterns"
   :type 'string
-  :set '(lambda (param value) (set-default param value))
+  :set (lambda (param value) (set-default param value))
   :group 'eide-project)
 (defcustom eide-custom-project-default-cscope-exclude-files ""
   "Default space separated list of files patterns to exclude when creating cscope
 list of files."
   :tag "Default cscope exclude files patterns"
   :type 'string
-  :set '(lambda (param value) (set-default param value))
+  :set (lambda (param value) (set-default param value))
   :group 'eide-project)
 (defcustom eide-custom-project-default-cscope-exclude-dirs ""
   "Default space separated list of directories patterns to exclude when creating
 cscope list of files."
   :tag "Default cscope exclude directories patterns"
   :type 'string
-  :set '(lambda (param value) (set-default param value))
+  :set (lambda (param value) (set-default param value))
   :group 'eide-project)
 (defcustom eide-custom-project-default-grep-exclude-files ""
   "Default space separated list of files patterns to exclude when searching with
 grep."
   :tag "Default grep exclude files patterns"
   :type 'string
-  :set '(lambda (param value) (set-default param value))
+  :set (lambda (param value) (set-default param value))
   :group 'eide-project)
 (defcustom eide-custom-project-default-grep-exclude-dirs ""
   "Default space separated list of directories patterns to exclude when searching
 with grep."
   :tag "Default grep exclude directories patterns"
   :type 'string
-  :set '(lambda (param value) (set-default param value))
+  :set (lambda (param value) (set-default param value))
   :group 'eide-project)
 
 ;; ----------------------------------------------------------------------------
@@ -1196,7 +1197,7 @@ list of the current workspace."
     (let ((l-available-style-name-list nil))
       ;; Build the list of available C styles
       (dolist (l-style c-style-alist)
-        (add-to-list 'l-available-style-name-list (car l-style)))
+        (push (car l-style) l-available-style-name-list))
       ;; Display the list
       (insert "# Possible C styles are:\n")
       (insert "#")
